Structs
Enums
- Connection
Mode - ConnectionMode is not directly withholding different host handlers like Ssh2(Ssh2HostHandler) because Serialize trait is not implemented for one of the Ssh2 structs. Instead, we pass the calling functions all parameters required to build one HostHandler to let the final worker binary build do it by itself.
- Privilege