pub struct TaskFlow {
pub name: Option<String>,
pub with_sudo: Option<bool>,
pub step_flows: Vec<StepFlow>,
pub task_status: TaskStatus,
}Expand description
A TaskFlow withholds all step flows, a flow being being the combination of :
- an expected state
- changes required to have the host match this expected state
- results of actually trying to enforce these changes
Fields
name: Option<String>with_sudo: Option<bool>step_flows: Vec<StepFlow>task_status: TaskStatusImplementations
Sourceimpl TaskFlow
impl TaskFlow
pub fn new() -> TaskFlow
pub fn from(task_block: TaskBlock) -> TaskFlow
pub fn dry_run( &mut self, hosthandler: &mut HostHandler, tera_context: &mut Context, ) -> Result<(), Error>
pub fn apply( &mut self, hosthandler: &mut HostHandler, tera_context: &mut Context, ) -> Result<(), Error>